@@ -2,9 +2,10 @@ package scale
 
 import (
 	"context"
-	"strconv"
 
+	"github.com/docker/go-units"
 	"github.com/spf13/cobra"
+	"github.com/superfly/flyctl/helpers"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/flag"
 )
@@ -30,10 +31,10 @@ func newScaleMemory() *cobra.Command {
 func runScaleMemory(ctx context.Context) error {
 	group := flag.GetString(ctx, "group")
 
-	memoryMB, err := strconv.ParseInt(flag.FirstArg(ctx), 10, 64)
+	memoryMB, err := helpers.ParseSize(flag.FirstArg(ctx), units.RAMInBytes, units.MiB)
 	if err != nil {
 		return err
 	}
 
-	return scaleVertically(ctx, group, "", int(memoryMB))
+	return scaleVertically(ctx, group, "", memoryMB)
 }
