@@ -4,9 +4,11 @@ import (
 	"context"
 	"fmt"
 
+	"github.com/docker/go-units"
 	"github.com/spf13/cobra"
 
 	"github.com/superfly/flyctl/flaps"
+	"github.com/superfly/flyctl/helpers"
 	"github.com/superfly/flyctl/iostreams"
 
 	"github.com/superfly/flyctl/client"
@@ -39,7 +41,7 @@ func newExtend() *cobra.Command {
 	flag.Add(cmd,
 		flag.App(),
 		flag.AppConfig(),
-		flag.Int{
+		flag.String{
 			Name:        "size",
 			Shorthand:   "s",
 			Description: "Target volume size in gigabytes",
@@ -72,11 +74,24 @@ func runExtend(ctx context.Context) error {
 		return err
 	}
 
-	sizeGB := flag.GetInt(ctx, "size")
+	sizeFlag := flag.GetString(ctx, "size")
+	sizeGB, err := helpers.ParseSize(sizeFlag, units.FromHumanSize, units.GB)
+	if err != nil {
+		return err
+	}
+
 	if sizeGB == 0 {
 		return fmt.Errorf("Volume size must be specified")
 	}
 
+	if sizeFlag[0] == '+' {
+		volume, err := flapsClient.GetVolume(ctx, volID)
+		if err != nil {
+			return err
+		}
+		sizeGB += volume.SizeGb
+	}
+
 	if app.PlatformVersion == "nomad" {
 		if !flag.GetYes(ctx) {
 			switch confirmed, err := prompt.Confirm(ctx, "Extending this volume will result in a VM restart. Continue?"); {
@@ -92,7 +107,7 @@ func runExtend(ctx context.Context) error {
 		}
 	}
 
-	volume, needsRestart, err := flapsClient.ExtendVolume(ctx, volID, flag.GetInt(ctx, "size"))
+	volume, needsRestart, err := flapsClient.ExtendVolume(ctx, volID, sizeGB)
 	if err != nil {
 		return fmt.Errorf("failed to extend volume: %w", err)
 	}
