@@ -8,9 +8,10 @@ import (
 	"github.com/dustin/go-humanize"
 	"github.com/spf13/cobra"
 
+	"github.com/superfly/flyctl/client"
+	"github.com/superfly/flyctl/flaps"
 	"github.com/superfly/flyctl/iostreams"
 
-	"github.com/superfly/flyctl/client"
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/config"
@@ -43,11 +44,21 @@ func newList() *cobra.Command {
 
 func runList(ctx context.Context) error {
 	cfg := config.FromContext(ctx)
-	client := client.FromContext(ctx).API()
+	apiClient := client.FromContext(ctx).API()
 
 	appName := appconfig.NameFromContext(ctx)
 
-	volumes, err := client.GetVolumes(ctx, appName)
+	app, err := apiClient.GetApp(ctx, appName)
+	if err != nil {
+		return err
+	}
+
+	flapsClient, err := flaps.NewFromAppName(ctx, appName)
+	if err != nil {
+		return err
+	}
+
+	volumes, err := flapsClient.GetVolumes(ctx)
 	if err != nil {
 		return fmt.Errorf("failed retrieving volumes: %w", err)
 	}
@@ -62,16 +73,23 @@ func runList(ctx context.Context) error {
 	for _, volume := range volumes {
 		var attachedVMID string
 
-		if volume.App.PlatformVersion == "machines" {
+		if app.PlatformVersion == "machines" {
 			if volume.AttachedMachine != nil {
-				attachedVMID = volume.AttachedMachine.ID
+				attachedVMID = *volume.AttachedMachine
 			}
 		} else {
-			if volume.AttachedAllocation != nil {
-				attachedVMID = volume.AttachedAllocation.IDShort
+			names, err := apiClient.GetAllocationTaskNames(ctx, appName)
+			if err != nil {
+				return err
+			}
 
-				if volume.AttachedAllocation.TaskName != "app" {
-					attachedVMID = fmt.Sprintf("%s (%s)", volume.AttachedAllocation.IDShort, volume.AttachedAllocation.TaskName)
+			if volume.AttachedAllocation != nil {
+				attachedVMID = *volume.AttachedAllocation
+
+				taskName, ok := names[*volume.AttachedAllocation]
+
+				if ok && taskName != "app" {
+					attachedVMID = fmt.Sprintf("%s (%s)", *volume.AttachedAllocation, taskName)
 				}
 			}
 		}
@@ -82,7 +100,7 @@ func runList(ctx context.Context) error {
 			volume.Name,
 			strconv.Itoa(volume.SizeGb) + "GB",
 			volume.Region,
-			volume.Host.ID,
+			volume.Zone,
 			fmt.Sprint(volume.Encrypted),
 			attachedVMID,
 			humanize.Time(volume.CreatedAt),
